@@ -42,16 +42,16 @@ from gajim.common.i18n import Q_
 from gajim.common.i18n import _
 from gajim.gtkgui_helpers import add_css_class
 
-from gajim.gtk.util import get_builder
-from gajim.gtk.util import get_icon_name
-from gajim.gtk.util import format_mood
-from gajim.gtk.util import format_activity
-from gajim.gtk.util import format_tune
-from gajim.gtk.util import format_location
-from gajim.gtk.util import get_css_show_class
+from .util import get_builder
+from .util import get_icon_name
+from .util import format_mood
+from .util import format_activity
+from .util import format_tune
+from .util import format_location
+from .util import get_css_show_class
 
 
-log = logging.getLogger('gajim.gtk.tooltips')
+log = logging.getLogger('gajim.gui.tooltips')
 
 
 class StatusTable:
@@ -91,8 +91,7 @@ class StatusTable:
                           1)
         self.current_row += 1
 
-    def add_status_row(self, show, str_status, show_lock=False,
-                       indent=True, transport=None):
+    def add_status_row(self, show, str_status, indent=True, transport=None):
         """
         Append a new row with status icon to the table
         """
@@ -117,10 +116,6 @@ class StatusTable:
         status_label.set_ellipsize(Pango.EllipsizeMode.END)
         status_label.set_max_width_chars(30)
         self.table.attach(status_label, 3, self.current_row, 1, 1)
-        if show_lock:
-            lock_image = Gtk.Image()
-            lock_image.set_from_icon_name('dialog-password', Gtk.IconSize.MENU)
-            self.table.attach(lock_image, 4, self.current_row, 1, 1)
         self.current_row += 1
 
     def fill_table_with_accounts(self, accounts):
@@ -128,8 +123,6 @@ class StatusTable:
             message = acct['message']
             message = helpers.reduce_chars_newlines(message, 100, 1)
             message = GLib.markup_escape_text(message)
-            con_type = app.con_types.get(acct['name'])
-            show_lock = con_type in ('tls', 'ssl')
 
             account_label = GLib.markup_escape_text(acct['account_label'])
             if message:
@@ -137,10 +130,7 @@ class StatusTable:
             else:
                 status = account_label
 
-            self.add_status_row(acct['show'],
-                                status,
-                                show_lock=show_lock,
-                                indent=False)
+            self.add_status_row(acct['show'], status, indent=False)
 
             for line in acct['event_lines']:
                 self.add_text_row('  ' + line, 1)
@@ -311,7 +301,7 @@ class RosterTooltip(StatusTable):
                 name=account_name,
                 show=get_connection_status(account),
                 status=connection.status_message,
-                resource=connection.get_own_jid().getResource(),
+                resource=connection.get_own_jid().resource,
                 priority=connection.priority)
 
             contacts.append(contact)
@@ -327,7 +317,7 @@ class RosterTooltip(StatusTable):
         self.contact_jid = self.prim_contact.jid
         name = GLib.markup_escape_text(self.prim_contact.get_shown_name())
 
-        if app.config.get('mergeaccounts'):
+        if app.settings.get('mergeaccounts'):
             name = GLib.markup_escape_text(
                 self.prim_contact.account.name)
 
@@ -367,7 +357,7 @@ class RosterTooltip(StatusTable):
 
         else:  # only one resource
             if contact.is_groupchat:
-                disco_info = app.logger.get_last_disco_info(contact.jid)
+                disco_info = app.storage.cache.get_last_disco_info(contact.jid)
                 if disco_info is not None:
                     description = disco_info.muc_description
                     if description:
@@ -508,7 +498,7 @@ class FileTransfersTooltip():
     def __init__(self):
         self.sid = None
         self.widget = None
-        if app.config.get('use_kib_mib'):
+        if app.settings.get('use_kib_mib'):
             self.units = GLib.FormatSizeFlags.IEC_UNITS
         else:
             self.units = GLib.FormatSizeFlags.DEFAULT
