@@ -14,15 +14,23 @@
 # You should have received a copy of the GNU General Public License
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
-import os
 import locale
 import gettext
+from pathlib import Path
 
 from gajim.common import configpaths
 
 DOMAIN = 'gajim_plugins'
-plugin_user_dir = configpaths.get('PLUGINS_USER')
-plugins_locale_dir = os.path.join(plugin_user_dir, 'locale')
+try:
+    plugin_user_dir = configpaths.get('PLUGINS_USER')
+except KeyError:
+    # This allows to import the module for tests
+    print('No plugin translation path available')
+    plugin_user_dir = Path.cwd()
+
+
+# python 3.7 gettext module does not support Path objects
+plugins_locale_dir = str(plugin_user_dir / 'locale')
 
 try:
     t = gettext.translation(DOMAIN, plugins_locale_dir)
